<?php
/**
 * @package   FL Badges Element for Zoo
 * @author    Дмитрий Васюков http://fictionlabs.ru
 * @license   http://www.gnu.org/licenses/gpl.html GNU/GPL
 */

class ElementFLBadges extends Element
{	
	// Has Value Function

	public function hasValue($params = array())
	{
		return true;
	}

	//Edit Function

    public function edit()
    {
        return $this->app->html->_('select.booleanlist', $this->getControlName('value'), '', $this->get('value', 1));
    }
	
	// Render Function

	public function render($params = array())
	{
		$params 			= $this->app->data->create($params);	
		$enableHit 			= $this->_config->get('enable_hit'); 
		$enableOrders 		= $this->_config->get('enable_orders'); 
		$enableNew 			= $this->_config->get('enable_new'); 
		$enableDiscount 	= $this->_config->get('enable_discount'); 

		$limitCount			= $this->_config->get('limit_orders');
		$limitNew			= $this->_config->get('limit_new');
		$limitHit			= $this->_config->get('limit_hit');

		$date				= $this->_config->get('date'); 
		$labelHit 			= $labelDiscount = $labelNew = $labelOrders = false;

		if ($enableHit) {
			$hit = $this->getItem()->hits;

			if ($hit > $limitHit) {
				$labelHit = true;
			}
		}

		if ($enableOrders) {
			$orders = $this->getOrdersCount();

			if ($orders > $limitHit) {
				$labelOrders = true;
			}
		}

		if ($enableNew) {
			switch ($date) {
				case 0:
					$newDate = $this->_item->created;
					break;
				case 1:
					$newDate = $this->_item->publish_up;
					break;
				case 2:
					$newDate = $this->_item->modified;
					break;

				default:
					$newDate = $this->_item->created;
					break;
			}

			$newDate = $this->app->html->_('date', $newDate, 'Y-m-d H:i:s', $this->app->date->getOffset());
			$different = strtotime($newDate) + $limitNew * 3600 - time();

			if ($different > 0) {
				$labelNew = true;
			}
		}

		if ($enableDiscount) {
			$elements = $this->getItem()->getElements();
			$discount = 0;

			if (!empty($elements)) {
				foreach ($elements as $key => $element) {
					if ($element->getElementType() == 'jbpriceplain' || $element->getElementType() == 'jbpricecalc') {
						$discount = $element->getList()->current()->get('_discount')->getValue()->text();
					}
				}
			}

			if ($discount) {
				$labelDiscount = true;
			}
		}
	
		if ($labelHit || $labelOrders || $labelNew || $labelDiscount) {	
			$layout = $this->getLayout('flbadges.php');

			return $this->renderLayout($layout, array(
				'labelHit' 		=> $labelHit,
				'labelOrders' 	=> $labelOrders,
				'labelNew'		=> $labelNew,
				'labelDiscount' => $labelDiscount
			));				
		}

		return false;
				    
    }
		
	// Get Orders Count Function

    public function getOrdersCount()
    {
        $id    = $this->getItem()->id;
        $cache = $this->app->cache->create($this->app->path->path('cache:') . '/flordercount', true, 86400);

        if (!$cache->check()) {
            $this->app->system->application->enqueueMessage('Cache not writable!', 'notice');
        }

        $cacheСheck = ($cache) ? $cache->check() : false;
        $cacheKey = md5($id);

        if ($cacheСheck) {
            $result = $cache->get($cacheKey);
        }

        if (empty($result)) {

            $status = $this->config->get('status');

            $status = array_map(function($value) {
                $statusArr = $this->app->jbcartstatus->getList(JBCart::STATUS_SHIPPING, true, false);

                if (isset($statusArr[$value])) {
                    return $statusArr[$value];
                }
                
            }, $status);

            $status = array_filter($status, function($value) { return $value != ''; });

            // Database

            $db = JFactory::getDbo();
            $query = $db->getQuery(true);

            $query->select('COUNT(*)');
            $query->from($db->quoteName('#__zoo_jbzoo_orders'));

            if ($status) {
                $query->where($db->quoteName('status').' IN \''.implode("','", $status).'\'');
            }

            $query->where($db->quoteName('items').' REGEXP \'"item_id":.*\.*"'.$id.'".*\'');

            $db->setQuery($query);
            $result = $db->loadResult();  

            $cache->set($cacheKey, $result);
            $cache->save();
        }

		return $result;
    }	

    // Set Config Folder Function

    public function getConfigForm()
    {
        $form = parent::getConfigForm();
        $form->addElementPath($this->app->path->path('elements:flbadges/fields'));
        return $form;
    }
}